%%
%% This is file `ais.cls',
%% 
\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{ais}
\typeout{XX}

\RequirePackage{xkeyval}
\RequirePackage{etoolbox}

\LoadClass[10pt]{article}
\RequirePackage[paperwidth=210mm,paperheight=275mm,left=68mm,right=15mm, top=27mm, bottom=23mm,footskip=5mm,headsep=5mm]{geometry}
%

\RequirePackage{lastpage,fancyhdr,graphicx}
\graphicspath{{figlogo/}{figures/}}
\ifodd\value{page}
\fancyheadoffset[L]{2.09in}
\fancyfootoffset[L]{2.09in}
\else
\fancyheadoffset[R]{2.09in}
\fancyfootoffset[R]{2.09in}
\fi
\RequirePackage{epstopdf}
\epstopdfsetup{suffix={}}
\RequirePackage{booktabs}
\RequirePackage{amsmath,amssymb,amsthm}

\RequirePackage{changepage,xifthen}
% Use Unicode characters when possible
\RequirePackage[utf8x]{inputenc}
% textcomp package and marvosym package for additional characters
% \usepackage{textcomp,marvosym}
\RequirePackage{mathptmx}
\RequirePackage[numbers,compress,square]{natbib}

\RequirePackage{nameref}
\RequirePackage[colorlinks,linkcolor=black,anchorcolor=black,citecolor=black]{hyperref}
% line numbers
% \usepackage[right]{lineno}
%\RequirePackage{indentfirst}
%\setlength{\parindent}{2em}
\RequirePackage{microtype}
\DisableLigatures[f]{encoding = *, family = * }
% color can be used to apply background shading to table cells only
\RequirePackage[table]{xcolor}
% array package and thick rules for tables
\RequirePackage{array}
% create "+" rule type for thick vertical lines
\newcolumntype{+}{!{\vrule width 2pt}}

% create \thickcline for thick horizontal lines of variable length
\newlength\savedwidth
\newcommand\thickcline[1]{%
  \noalign{\global\savedwidth\arrayrulewidth\global\arrayrulewidth 2pt}%
  \cline{#1}%
  \noalign{\vskip\arrayrulewidth}%
  \noalign{\global\arrayrulewidth\savedwidth}%
}

% \thickhline command for thick horizontal lines that span the table
\newcommand\thickhline{\noalign{\global\savedwidth\arrayrulewidth\global\arrayrulewidth 2pt}%
\hline
\noalign{\global\arrayrulewidth\savedwidth}}


% Remove comment for double spacing
\RequirePackage{setspace} 
%\doublespacing


% Bold the 'Figure #' in the caption and separate it from the title/caption with a period
% Captions will be left justified
\RequirePackage{caption}
\DeclareCaptionLabelSeparator{newperiod}{\textcolor{aistext}{. }}
\captionsetup{labelsep=newperiod}
\captionsetup{aboveskip=1pt,labelfont=bf,justification=raggedright,singlelinecheck=off}
\renewcommand{\figurename}{\textcolor{aistext}{Figure}}
\renewcommand{\tablename}{\textcolor{aistext}{Table}}
\renewcommand{\thetable}{\textcolor{aistext}{\arabic{table}}}
\renewcommand{\thefigure}{\textcolor{aistext}{\arabic{figure}}}


\fancypagestyle{myaisheadings}{%
\fancyhf{}%
\lhead{\includegraphics[width=3.4cm]{ais.pdf}}
\rhead{\hfill\vbox{\fontsize{8}{12}\selectfont%
\hfill\hbox{\bf \textcolor{aistext}{\ope@journal, \ope@year, \ope@vol, \ope@firstpage--\pageref*{LastPage}}}\\%
\hfill\hbox{https://iecscience.org/journals/\ope@abbjournal}\\%
\hfill\hbox{ISSN Online:~\ope@ISSNOnline}\\[1mm]}}
\lfoot{\textcolor{aistext}{\ope@doifoot~\ope@Published}}
\cfoot{\thepage}
\rfoot{\textcolor{aistext}{\ope@journal}}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrule}{\hrule height 0.4pt \vspace{2mm}}}

\fancypagestyle{myaisfancy}{%
\fancyhf{}%
\lhead{\ope@RuningheadAuthorName}
\lfoot{\textcolor{aistext}{\ope@doifoot}}
\cfoot{\thepage}
\rfoot{\textcolor{aistext}{\ope@journal}}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrule}{\hrule height 0.4pt \vspace{1mm}}}
\pagestyle{myaisfancy}


\RequirePackage{enumitem}
\setenumerate[1]{itemsep=0pt,partopsep=0pt,parsep=\parskip,topsep=0pt}
\setitemize[1]{itemsep=0pt,partopsep=0pt,parsep=\parskip,topsep=0pt}
\setdescription{itemsep=0pt,partopsep=0pt,parsep=\parskip,topsep=0pt}

\RequirePackage{calc,float}
\RequirePackage{environ}

\RenewEnviron{abstract}{\xdef\@abstract{\BODY}}
\def\make@abstract{\setlength\parindent{0em}%
{\color{aistext}\rule[2pt]{\textwidth}{0.8pt}}
\begin{spacing}{1.5}
{\fontsize{12}{12}\selectfont\textcolor{aistext}{\textbf{\abstractname}}}
\end{spacing}\par
\@abstract\par}

\NewEnviron{keywords}{\xdef\@keywords{\BODY}}
\def\make@keywords{\setlength\parindent{0em}%
\begin{spacing}{1.5}
{\fontsize{12}{12}\selectfont\textcolor{aistext}{\textbf{\keywordsname}}}
\end{spacing}
\par
\@keywords\par{\color{aistext}\rule[2pt]{\textwidth}{0.8pt}}}


% keys
\renewcommand{\title}[1]{\gdef\ope@title{#1}}
\renewcommand{\author}[1]{\gdef\ope@author{\fontsize{12}{12}\selectfont\bf #1}}
\renewcommand{\citeauthor}[1]{\gdef\ope@citeauthor{#1}}
\newcommand{\address}[1]{\gdef\ope@address{#1}}
\newcommand{\RuningheadAuthorName}[1]{\gdef\ope@RuningheadAuthorName{#1}}
\newcommand{\CorrespondingAuthorName}[1]{\gdef\ope@CorrespondingAuthorName{#1}}
\newcommand{\CorrespondingAuthorEmail}[1]{\gdef\ope@CorrespondingAuthorEmail{#1}}
\newcommand{\Email}[1]{Email:~#1}
\newcommand{\Volume}[3]{%
\gdef\ope@year{#1}%
\gdef\ope@vol{#2}%
\gdef\ope@firstpage{#3}}
\newcommand{\doi}[1]{\gdef\ope@doi{https://doi.org/10.33969/\ope@abbjournal.\ope@year.#1}\gdef\ope@doifoot{DOI:~10.33969/\ope@abbjournal.\ope@year.#1}}
\newcommand{\paperdate}[3]{%
\gdef\ope@Received{#1}%
\gdef\ope@Accepted{#2}%
\gdef\ope@Published{#3}}
\newcommand{\journal}[1]{\gdef\ope@journal{#1}}
\newcommand{\abbjournal}[1]{\gdef\ope@abbjournal{#1}}
%\journal{Journal of Artificial Intelligence and Systems}
\newcommand{\ISSNOnline}[1]{\gdef\ope@ISSNOnline{#1}}
\renewcommand{\abstractname}[1]{Abstract}
\newcommand{\keywordsname}[1]{Keywords}


\def\maketitle{%
\ifthenelse{\equal{\thepage}{1}}{\thispagestyle{myaisheadings}}{\pagestyle{myaisfancy}}
\setcounter{page}{1}
\newpage
\vspace*{3\baselineskip}\vskip3mm%
\begin{adjustwidth}{-2.09in}{0in}
\centering
{\fontsize{20}{20}\selectfont\bf \ope@title}
\par\vspace*{2\baselineskip}\vskip2.8mm%
{\ope@author}
\par\vspace*{1\baselineskip}%\vskip2.8mm%
\begin{spacing}{1.14}\fontsize{10}{10}\selectfont%
\ope@address\par
*Corresponding Author:~\ope@CorrespondingAuthorName, Email:~\ope@CorrespondingAuthorEmail
\end{spacing}
\end{adjustwidth}
\begin{adjustwidth}{-2.09in}{5.2in}
\begin{minipage}[t]{1.94in}
\tolerance=1%
\emergencystretch=\maxdimen
\hyphenpenalty=10000
\hbadness=10000
\vbox to 2.5in{
\fontsize{8}{8}\selectfont%
\setlength\parindent{0em}%
How to cite this paper: \ope@citeauthor~(\ope@year) \ope@title. \ope@journal, \ope@vol, \ope@firstpage--\pageref*{LastPage}.
\par
\ope@doi
\par
\vskip2.8mm
{\bf Received:} \ope@Received
\par
{\bf Accepted:} \ope@Accepted
\par
{\bf Published:} \ope@Published
\vskip2.8mm
\par
Copyright~©~\ope@year~by author(s) and Institute of Electronics and Computer. This work is licensed under the Creative Commons Attribution International License (CC BY 4.0).\\
http://creativecommons.org/licenses/by/4.0/\\
\includegraphics{ccby.pdf}
\includegraphics{openaccess.pdf}}%
\end{minipage}%
\vspace*{-2.65in}
\end{adjustwidth}
\make@abstract\par
\make@keywords
\setlength{\parindent}{0.5cm}
}

\definecolor{aistext}{HTML}{943634}
\RequirePackage{titlesec}

\titleformat {\section} [block] {\raggedright \fontsize{12}{12}\selectfont\bfseries\color{aistext}} {\thesection.\space} {0pt} {}
\titlespacing*{\section}{0pt}{3.5ex plus 1ex minus .2ex}{2.3ex plus .2ex}{}
%{0pt} {21pt} {13pt}
%\setlength{\parskip}{0em}

\titleformat {\subsection} [block] {\raggedright \fontsize{12}{12}\selectfont\bfseries\color{aistext}} {\thesubsection.\space} {0pt} {}
\titlespacing*{\subsection}{0pt}{3.5ex plus 1ex minus .2ex}{2.3ex plus .2ex}{}

\titleformat {\subsubsection} [block] {\raggedright \fontsize{10}{10}\selectfont\color{aistext}} {\thesubsubsection.\space} {0pt} {}
\titlespacing*{\subsubsection}{0pt}{3.5ex plus 1ex minus .2ex}{2.3ex plus .2ex}{}

\titleformat {\paragraph} [block] {\raggedright \fontsize{10}{10}\selectfont\color{aistext}} {} {0pt} {}
\titlespacing {\paragraph}{0pt}{3.5ex plus 1ex minus .2ex}{2.3ex plus .2ex}{}



%% END MACROS SECTION
\tolerance=1%
\emergencystretch=\maxdimen
\hyphenpenalty=10000
\hbadness=10000
\setlength{\parindent}{0.5cm}

\endinput
